<?php

require_once('../../config.php');
require_once ('entity/block_mahara_iena_connexion.php');

global $COURSE, $DB, $USER, $CFG;

$courseid = required_param('courseid', PARAM_INT);
$url = new moodle_url('/blocks/mahara_iena/mahara_iena_groups_all.php',array('courseid' => $courseid));

$PAGE->set_pagelayout('course');
$PAGE->set_url($url);

$course = $DB->get_record('course', array('id'=>$courseid), '*', MUST_EXIST);
require_login($course, false, NULL);

if (!has_capability('moodle/course:update', $context = context_course::instance($courseid), $USER->id)) {
	header("Location: {$_SERVER['HTTP_REFERER']}");
	exit;
}

$PAGE->set_title(get_string('title_plugin', 'block_mahara_iena', $CFG->mahara_alias));
$PAGE->set_heading($OUTPUT->heading($COURSE->fullname, 2, 'headingblock header outline'));
echo $OUTPUT->header();

/* Crée dans Mahara un groupe pour chaque groupe existant dans le cours
*  Si au départ, un seul groupe avait été créé pour tout le cours, alors maintenant
*  il y en aura plusieurs (si il y a plusieurs groupe). 
*/
if ( $_GET['create_all_groups'] ) {

	$content = "";

	/* tous les groupes du cours */
	$mo_course_groups = groups_get_all_groups($COURSE->id, 0, 0);

	/* toutes les association cours - groupe moodle - groupe mahara */
	$mo_ma_groups = $DB->get_records_sql('SELECT * FROM {block_mahara_iena} WHERE course = ?', array($COURSE->id));

	/* stockera les nouvelles associations */
	$created_associations = [];
	
	/* en cas d'erreur pour un message à la fin */
	$errors = 0;

	$block_mahara_iena_connexion = new block_mahara_iena_connexion($CFG->wstoken,$CFG->base_mahara);

	/* pour chaque groupe du cours */
	foreach ($mo_course_groups as $mo_course_group) {
		$mo_ma_exists = false;
		/* pour chaque groupe déjà enregistré et donc existant */
		foreach ($mo_ma_groups as $mo_ma_group) {
			/* si le cours est déjà dans la base */
			if ( $mo_course_group->id == $mo_ma_group->moodle_group_id ) {
				$block_mahara_iena_connexion->ensure_user_is_mahara_group_member_new($USER, $mo_ma_group->mahara_group_id, null);
				$mo_ma_exists = true;
			}
		}
		/* si le cours n'est pas dans la base */
		if ( $mo_ma_exists === false ) {
			/* stocker le nom des groupes pour un message de confirmation */
			$succeed = $block_mahara_iena_connexion->create_mahara_group($mo_course_group, $USER);
			if ( $succeed == true ) {
				$created_associations[] = $mo_course_group->name;
			} else {
				$errors += 1;
			}
		}
	}

	/* afficher le nom des groupes créés pour une association pour un message de confirmation */
	if ( count($created_associations) !== 0 ) {
		$content .= "<div class='alert alert-success'><p>Des groupes ont été créés dans " . $CFG->mahara_alias . " : </p>
		<ul style='margin-left: 1.2rem;'>";
		foreach ($created_associations as $created_association) {
			$content .= '<li>Groupe : "' . $created_association . '"</li>';
		}
		$content .= "</ul></div>";
	} else {
		if ( $errors === true ) {
			$content .= "<div class='alert alert-danger'><p>Une ou plusieurs erreurs se sont produites pendant la création des groupes sur " . $CFG->mahara_alias . ".</p></div>";
		} else {
			$content .= "<div class='alert alert-secondary'><p>Aucun groupe n'a été créé dans " . $CFG->mahara_alias . ". Il doivent déjà exister. </p></div>";
		}
	}

	$content .= "<a class='btn btn-primary' href='" . $CFG->wwwroot . "/course/view.php?id=" . $_GET['courseid'] . "'>Retour au cours</a>";

	echo $content;

} else {

	// ceci ne devrait plus être utilisé, c'était dans le cas où on voulait inscrire un ens. à tous les groupes existant, mais ceci est assuré par le bouton qui créé tous les groupes et y inscrit l'ens. donc ce n'est plus forcément nécessaire. le bouton pour simplement s'inscrire à tous les groupes a été supprimé. 
	// cependant, un enseignant pourrait vouloir s'inscrire à tous les groupes sans pour autant chercher à les créer donc il faudrait rajouter un bouton alternatif ; actuellement, l'ens. ne semble pas inscrit aux groupes qui existent déjà
	// idéalement, un ens. devrait pouvoir choisir de créer tous les groupes sans forcément s'y inscrire et de s'inscrire et se désinscrire de tous les groupes (attention, il est préférable de ne pas laisser de groupes abandonnés donc pas de désinscription si l'ens. est le seul membre restant (et même le seul parmi les admin du groupe)). 

	// obtenir l'utilisateur
	// checker qu'il est enseignant ("editingteacher")
	// récupérer tous les groupes mahara liés au cours
	// pour chaque groupe mahara lié au cours
		// récupérer si l'utilisateur est membre du groupe mahara
		// si non membre du groupe mahara : update group pour inscrire
	// message de confirmation ou d'erreur

	$result = $DB->get_records_sql('SELECT * FROM {block_mahara_iena} WHERE course = ?', array($COURSE->id));

	$connexion = new block_mahara_iena_connexion($CFG->wstoken,$CFG->base_mahara);

	$errors = 0;
	$succeed = 0;
	foreach ($result as $record) {
		$success = $connexion->ensure_user_is_mahara_group_member($USER, $record->mahara_group_id);
		if ( !$success ) {
			$errors += 1;
		} else {
			$succeed += 1;
		}
	}

	$content = "";

	if ( $errors > 0 ) {
		$content .= '<div class="alert alert-danger">L\'inscription a échoué dans '.$errors.' groupes sur.</div>';
	} 

	$content .= '<div class="alert alert-success">L\'inscription a été effectuée dans '.$succeed.' groupes.</div>';

	$content .= "<a href=\"".$CFG->wwwroot."/course/view.php?id=".$COURSE->id." \" class=\"btn btn-primary\" role=\"button\">".get_string('back_course', 'block_mahara_iena')."</a>";

	echo $content;

}

echo $OUTPUT->footer();
